@@ -105,16 +105,16 @@ mod tests {
         async fn can_send_receive_messages_bidirectional(
             #[case] is_forward_direction: bool,
         ) {
-            use crate::test::random_vector_rg;
+            use crate::test::random_vec_rg;
             use crate::swap;
 
             let (stream1, stream2) = duplex(4096);
             
-            let stream1_messages = random_vector_rg(4..8);
+            let stream1_messages = random_vec_rg(4..8);
             let stream1_messages1 = stream1_messages.clone();
             let stream1_messages2 = stream1_messages.clone();
 
-            let stream2_messages = random_vector_rg(4..8);
+            let stream2_messages = random_vec_rg(4..8);
             let stream2_messages1 = stream2_messages.clone();
             let stream2_messages2 = stream2_messages.clone();
 
@@ -240,7 +240,7 @@ mod tests {
         async fn can_send_receive_messages_bidirectional(
             #[case] is_forward_direction: bool,
         ) {
-            use crate::test::random_vector_rg;
+            use crate::test::random_vec_rg;
             use crate::swap;
 
             impl Random for String {
@@ -251,11 +251,11 @@ mod tests {
 
             let (stream1, stream2) = duplex(4096);
             
-            let stream1_messages = random_vector_rg(4..8);
+            let stream1_messages = random_vec_rg(4..8);
             let stream1_messages1 = stream1_messages.clone();
             let stream1_messages2 = stream1_messages.clone();
 
-            let stream2_messages = random_vector_rg(4..8);
+            let stream2_messages = random_vec_rg(4..8);
 
             let stream2_messages1 = stream2_messages.clone();
             let stream2_messages2 = stream2_messages.clone();
